# Copyright (c) 2010-2011 David Love
#
# Permission to use, copy, modify, and/or distribute this software for 
# any purpose with or without fee is hereby granted, provided that the 
# above copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES 
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF 
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR 
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES 
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN 
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF 
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

# @author David Love

# 
# This test suite checks for the correct behaviour of the file/dir projection
#
module Test::Projections
  
  require "projections"
  
  # Include the standard projections
  include WhiteCloth::Projections
  
  require "gibberish"
  
  # Check that we can read the file we will shortly be testing
  context "Load Welcome.byx" do
    setup   { 
      file_contents = String.new
      file = File.new("test/data/bayeux/Welcome.byx", "r")
      while (line = file.gets)
        file_contents << line
      end
      file.close
      file_contents
    }
    asserts_topic.kind_of(String)
    asserts("file is not empty") { !topic.empty? }
  end
  
  # Sanity check the +Gibberish+ library (this has it own test suite, which
  # should be used for checking the behaviour against specification: this test
  # mereley looks at whether we can load the correct library and get an
  # expected result)
  context "Checksum Welcome.byx using Gibberish" do
    setup { 
      file_contents = String.new
      file = File.new("test/data/bayeux/Welcome.byx", "r")
      while (line = file.gets)
        file_contents << line
      end
      file.close
      file_contents
    }
    asserts("can run SHA-256 checksum") { Gibberish::SHA256(topic) }
    asserts_topic.kind_of(String)
    asserts("checksum") { Gibberish::SHA256(topic) }.equals("0f1602b15e73725bea9dcb4e4a3da871339399f1b5e990f99ec8ff108d40deee")    
  end
  
  # Check that we can instantiate a directory projection
  #context "Create an empty DirFileWitness projection" do
  #  setup { DirFile.new }
  #  asserts_topic.kind_of(WhiteCloth::Projections::DirFile)
  #end
  
  # Create a walker for the test data
  #context "Create a DirFileWitness projection for \"test/data/bayeux/**/*.byx\"" do
  #  setup { DirFile.new }
  #  asserts("directory walker"){ topic.project("test/data/bayeux/**/*.byx") }
  #end
    
end

